import type { RuntimeContext } from '../runtime/types';
import type { IPointerEvent, State } from '../types';
import type { ShortcutKey } from '../utils/shortcut';
import type { BaseBehaviorOptions } from './base-behavior';
import { BaseBehavior } from './base-behavior';
export interface ClickElementOptions extends BaseBehaviorOptions {
    /**
     * <zh/> 是否启用动画
     *
     * <en/> Whether to enable animation
     */
    animation?: boolean;
    /**
     * <zh/> 是否启用点击元素的功能
     *
     * <en/> Whether to enable the function of clicking the element
     */
    enable?: boolean | ((event: IPointerEvent) => boolean);
    /**
     * <zh/> 是否允许多选
     *
     * <en/> Whether to allow multiple selection
     */
    multiple?: boolean;
    /**
     * <zh/> 按下该快捷键配合鼠标点击进行多选
     *
     * <en/> Press this shortcut key to apply multiple selection with mouse click
     */
    trigger?: ShortcutKey;
    /**
     * <zh/> 选中时应用的状态，默认为 selected
     *
     * <en/> The state to be applied when select.
     */
    selectedState: State;
    /**
     * <zh/> 当有元素被选中时，其他未选中的元素应用的状态，默认为 undefined
     *
     * <en/> The state to be applied on other unselected elements when some elements are selected
     */
    unselectedState: State;
    /**
     * <zh/> 选中元素的度，即决定了影响范围
     *
     * <en/> The degree to determine the scope of influence
     * @description
     * <zh/> 对于节点来说，
     * - 0 表示只选中当前节点
     * - 1 表示选中当前节点及其直接相邻的节点和边，以此类推
     * 对于边来说，
     * - 0 表示只选中当前边
     * - 1 表示选中当前边及其直接相邻的节点，以此类推
     *
     * <en/> For nodes,
     * - 0 means only the current node is selected
     * - 1 means the current node and its directly adjacent nodes and edges are selected, etc
     * For edges,
     * - 0 means only the current edge is selected
     * - 1 means the current edge and its directly adjacent nodes are selected, etc
     */
    degree?: number;
}
export declare class ClickElement extends BaseBehavior<ClickElementOptions> {
    private selectedElementIds;
    private shortcut;
    static defaultOptions: Partial<ClickElementOptions>;
    constructor(context: RuntimeContext, options: ClickElementOptions);
    private bindEvents;
    private onClickElement;
    private onClickCanvas;
    private updateElementsState;
    private getElementsState;
    private validate;
    private unbindEvents;
    destroy(): void;
}
