import type { ID } from '@antv/graphlib';
import type { RuntimeContext } from '../runtime/types';
import type { EdgeData } from '../spec';
import type { EdgeStyle } from '../spec/element/edge';
import type { IPointerEvent } from '../types';
import type { BaseBehaviorOptions } from './base-behavior';
import { BaseBehavior } from './base-behavior';
export interface CreateEdgeOptions extends BaseBehaviorOptions {
    /**
     * <zh/> 是否启用悬浮元素的功能
     *
     * <en/> Whether to enable hover element function.
     */
    enable?: boolean | ((event: IPointerEvent) => boolean);
    /**
     * <zh/> 边配置
     *
     * <en/> edge config.
     */
    style?: EdgeStyle;
    /**
     * <zh/> 交互配置 点击 或 拖拽
     *
     * <en/> trigger click or drag.
     */
    trigger?: 'click' | 'drag';
    /**
     * <zh/> 成功创建边回调
     *
     * <en/> Callback when create is completed.
     */
    onFinish?: (edge: EdgeData) => void;
    /**
     * <zh/> 创建边回调，返回边数据
     *
     * <en/> Callback when create edge, return EdgeData.
     */
    onCreate?: (edge: EdgeData) => EdgeData;
}
export declare class CreateEdge extends BaseBehavior<CreateEdgeOptions> {
    static defaultOptions: Partial<CreateEdgeOptions>;
    source?: ID;
    constructor(context: RuntimeContext, options: CreateEdgeOptions);
    update(options: Partial<CreateEdgeOptions>): void;
    private bindEvents;
    private drop;
    private handleCreateEdge;
    private updateAssistEdge;
    private createEdge;
    private cancelEdge;
    private getSelectedNodeIDs;
    private validate;
    private unbindEvents;
    destroy(): void;
}
