import type { RuntimeContext } from '../runtime/types';
import type { IPointerEvent, State } from '../types';
import type { BaseBehaviorOptions } from './base-behavior';
import { BaseBehavior } from './base-behavior';
export interface HoverElementOptions extends BaseBehaviorOptions {
    /**
     * <zh/> 是否启用动画
     *
     * <en/> Whether to enable animation
     */
    animation?: boolean;
    /**
     * <zh/> 是否启用悬浮元素的功能
     *
     * <en/> Whether to enable hover element function
     */
    enable?: boolean | ((event: IPointerEvent) => boolean);
    /**
     * <zh/> 激活元素的n度关系，默认为0，表示只激活当前节点，1表示激活当前节点及其直接相邻的节点和边，以此类推
     *
     * <en/> N-degree relationship of the hovered element, default to 0, which means only the current node is activated, 1 means the current node and its directly adjacent nodes and edges are activated, etc
     */
    degree?: number;
    /**
     * <zh/> 激活元素的状态，默认为 active
     *
     * <en/> Active element state, default to active
     */
    activeState?: State;
    /**
     * <zh/> 非激活元素的状态，默认为 default
     *
     * <en/> Inactive element state, default to default
     */
    inactiveState?: State;
    /**
     * <zh/> 当元素被悬停时的回调
     *
     * <en/> Callback when the element is hovered
     */
    onHover?: (event: IPointerEvent) => void;
    /**
     * <zh/> 当悬停结束时的回调
     *
     * <en/> Callback when the hover ends
     */
    onHoverEnd?: (event: IPointerEvent) => void;
}
export declare class HoverElement extends BaseBehavior<HoverElementOptions> {
    static defaultOptions: Partial<HoverElementOptions>;
    constructor(context: RuntimeContext, options: HoverElementOptions);
    private bindEvents;
    private hoverElement;
    private hoverEndElement;
    private updateElementsState;
    private getElementsState;
    private validate;
    private unbindEvents;
    destroy(): void;
}
