import type { DisplayObjectConfig, Group, PathStyleProps } from '@antv/g';
import type { LabelStyleProps } from '../../elements/shapes';
import { BaseShape } from '../../elements/shapes';
import type { CardinalPlacement, PrefixObject } from '../../types';
type HullLabelStyleProps = LabelStyleProps & {
    /**
     * <zh/> 标签位置，可选值为 'top'、'right'、'bottom'、'left'、'center'；默认为 'bottom'
     * <en/> Label position, optional values are 'top', 'right', 'bottom', 'left', 'center'; default is 'bottom'
     */
    placement?: CardinalPlacement | 'center';
    /**
     * <zh/> 标签是否贴合轮廓，默认为 true
     * <en/> Whether the label is close to the contour, default is true
     */
    closeToHull?: boolean;
    /**
     * <zh/> 标签是否跟随轮廓旋转，默认为 true，仅在 closeToHull 为 true 时生效
     * <en/> Whether the label rotates with the contour, default is true. Only effective when closeToHull is true
     */
    autoRotate?: boolean;
    /**
     * <zh/> x 轴偏移量
     * <en/> Label x-axis offset
     */
    offsetX?: number;
    /**
     * <zh/> y 轴偏移量
     * <en/> Label y-axis offset
     */
    offsetY?: number;
    /**
     * <zh/> 文本的最大宽度，超出会自动省略
     * <en/> The maximum width of the text, which will be automatically ellipsis if exceeded
     */
    maxWidth?: number;
};
export type HullStyleProps = PathStyleProps & {
    label?: boolean;
} & PrefixObject<HullLabelStyleProps, 'label'>;
type ParsedHullStyleProps = Required<HullStyleProps>;
type HullOptions = DisplayObjectConfig<HullStyleProps>;
export declare class Hull extends BaseShape<HullStyleProps> {
    static defaultStyleProps: Partial<HullStyleProps>;
    constructor(options: HullOptions);
    protected getLabelStyle(attributes: ParsedHullStyleProps): LabelStyleProps | false;
    protected getContourStyle(attributes: ParsedHullStyleProps): Omit<Required<HullStyleProps>, "transform" | "x" | "y" | "z" | "zIndex" | "className" | "transformOrigin" | "context">;
    render(attributes: ParsedHullStyleProps, container: Group): void;
}
export {};
