import type { TooltipStyleProps } from '@antv/component';
import type { RuntimeContext } from '../runtime/types';
import type { Element, ElementDatum, ElementType, IPointerEvent } from '../types';
import type { BasePluginOptions } from './base-plugin';
import { BasePlugin } from './base-plugin';
export interface TooltipOptions extends BasePluginOptions, Pick<TooltipStyleProps, 'position' | 'offset' | 'enterable' | 'style' | 'container'> {
    /** <zh/> 触发方式 | <en/> Event type that triggers display of tooltip */
    trigger?: 'hover' | 'click';
    /** <zh/> 自定义内容 | <en/> Function for getting tooltip content  */
    getContent?: (evt: IElementEvent, items: ElementDatum[]) => HTMLElement | string;
    /** <zh/> 是否启用 | <en/> Is enable */
    enable?: boolean | ((evt: IElementEvent) => boolean);
}
export declare class Tooltip extends BasePlugin<TooltipOptions> {
    static defaultOptions: Partial<TooltipOptions>;
    private currentTarget;
    private tooltipElement;
    private container;
    constructor(context: RuntimeContext, options: TooltipOptions);
    getEvents(): {
        [key: string]: (event: IElementEvent) => void;
    };
    update(options: Partial<TooltipOptions>): void;
    private render;
    private unbindEvents;
    private bindEvents;
    private isEnable;
    onClick: (e: IElementEvent) => void;
    onPointerMove: (e: IElementEvent) => void;
    onPointerLeave: (e: IElementEvent) => void;
    onCanvasMove: (e: IElementEvent) => void;
    private onPointerEnter;
    showTooltipById: (id: string, elementType?: ElementType) => void;
    private getItems;
    showTooltip: (e: IElementEvent) => void;
    hideTooltip: (e?: IElementEvent) => void;
    private initTooltip;
    destroy(): void;
}
type IElementEvent = IPointerEvent<Element>;
export {};
