import type { DisplayObject, IAnimation } from '@antv/g';
import type { ID } from '@antv/graphlib';
import type { AnimationStage } from '../spec/element/animation';
import type { Combo, Element, ElementDatum, ElementType, Node, State } from '../types';
import type { RuntimeContext } from './types';
export declare class ElementController {
    private context;
    private container;
    private elementMap;
    private shapeTypeMap;
    constructor(context: RuntimeContext);
    init(): void;
    private emit;
    private forEachElementData;
    private getTheme;
    getThemeStyle(elementType: ElementType): import("../spec/element/node").NodeStyle | import("../spec/element/edge").EdgeStyle;
    getThemeStateStyle(elementType: ElementType, states: State[]): any;
    private paletteStyle;
    private computePaletteStyle;
    getPaletteStyle(id: ID): {
        color?: undefined;
    } | {
        color: string;
    };
    private defaultStyle;
    /**
     * <zh/> 计算单个元素的默认样式
     *
     * <en/> compute default style of single element
     */
    private computedElementDefaultStyle;
    private computeElementsDefaultStyle;
    getDefaultStyle(id: ID): Record<string, unknown>;
    private getElementState;
    private stateStyle;
    /**
     * <zh/> 获取单个元素的单个状态的样式
     *
     * <en/> get single state style of single element
     */
    private getElementStateStyle;
    /**
     * <zh/> 计算单个元素的合并状态样式
     *
     * <en/> compute merged state style of single element
     */
    private computeElementStatesStyle;
    /**
     * <zh/> 计算全部元素的状态样式
     *
     * <en/> compute state style of all elements
     * @param ids - <zh/> 计算指定元素的状态样式 | <en/> compute state style of specified elements
     */
    private computeElementsStatesStyle;
    getStateStyle(id: ID): Record<string, unknown>;
    private computeStyle;
    getElement<T extends Element>(id: ID): T | undefined;
    getNodes(): Node[];
    getEdges(): import("..").BaseEdge[];
    getCombos(): Combo[];
    private getAnimation;
    private getAnimationExecutor;
    /**
     * <zh/> 获取边端点连接上下文
     *
     * <en/> Get edge end context
     * @param id - <zh/> 边 id | <en/> edge id
     * @returns <zh/> 边端点连接上下文 | <en/> edge end context
     * @description
     * <zh/> 只提供了最基本的节点示例和连接点位置信息，更多的上下文信息需要在边元素中计算
     *
     * <en/> Only the most basic node instances and connection point position information are provided, and more context information needs to be calculated in the edge element
     */
    private getEdgeEndsContext;
    getElementComputedStyle(elementType: ElementType, datum: ElementDatum): any;
    /**
     * <zh/> 开始绘制流程
     *
     * <en/> start render process
     */
    draw(drawContext?: DrawContext): Promise<void>;
    private computeChangesAndDrawData;
    private transformData;
    private createElement;
    private getCreateTasks;
    /**
     * <zh/> 由于 show 和 hide 的时序存在差异
     * - show： 立即将元素显示出来，然后执行动画
     * - hide： 先执行动画，然后隐藏元素
     *
     * 如果在调用 hide 后立即调用 show，hide 动画完成后会将元素隐藏
     *
     * 因此需要缓存元素最新的可见性
     *
     * <en/> Due to the difference in the timing of show and hide
     * - show: immediately shows the element and then executes the animation
     * - hide: executes the animation first, and then hides the element
     *
     * If show is called immediately after hide,it hide the element after hide animation completed
     *
     * Therefore, the latest visibility of the element needs to be cached
     */
    private latestElementVisibilityMap;
    private updateElement;
    private getUpdateTasks;
    private destroyElement;
    private getDestroyTasks;
    private clearElement;
    destroy(): void;
}
type AnimationExecutor = (id: ID, shape: DisplayObject, originalStyle: Record<string, unknown>, modifiedStyle?: Record<string, unknown>) => IAnimation | null;
type DrawContext = {
    animator?: AnimationExecutor;
    /** <zh/> 是否使用动画，默认为 true | <en/> Whether to use animation, default is true */
    animation: boolean;
    /** <zh/> 当前绘制阶段 | <en/> Current draw stage */
    stage?: AnimationStage;
    /** <zh/> 是否不抛出事件 | <en/> Whether not to throw events */
    silence?: boolean;
};
export {};
