import { isFunction } from '@antv/util';
import { CommonEvent } from '../constants';
import { isElement } from '../utils/element';
import { BaseBehavior } from './base-behavior';
export class CollapseExpand extends BaseBehavior {
    static defaultOptions = {
        enable: true,
        animation: true,
    };
    constructor(context, options) {
        super(context, Object.assign({}, CollapseExpand.defaultOptions, options));
        this.bindEvents();
    }
    bindEvents() {
        const { graph } = this.context;
        this.unbindEvents();
        graph.on(`combo:${CommonEvent.DBLCLICK}`, this.onCollapseExpand);
    }
    unbindEvents() {
        const { graph } = this.context;
        graph.off(`combo:${CommonEvent.DBLCLICK}`, this.onCollapseExpand);
    }
    onCollapseExpand = async (event) => {
        if (!this.validate(event))
            return;
        const { target } = event;
        if (!isElement(target))
            return;
        const id = target.id;
        const { model, graph } = this.context;
        const data = model.getComboData([id])[0];
        if (!data)
            return false;
        const { onCollapse, onExpand, animation } = this.options;
        const isCollapse = data.style?.collapsed;
        if (isCollapse) {
            await graph.expand(id, animation);
            onExpand?.(id);
        }
        else {
            await graph.collapse(id, animation);
            onCollapse?.(id);
        }
    };
    validate(event) {
        if (this.destroyed)
            return false;
        const { enable } = this.options;
        if (isFunction(enable))
            return enable(event);
        return !!enable;
    }
    destroy() {
        this.unbindEvents();
        super.destroy();
    }
}
//# sourceMappingURL=collapse-expand.js.map