import { idOf } from '../utils/id';
import { add } from '../utils/vector';
import { DragElement } from './drag-element';
export class DragElementForce extends DragElement {
    get forceLayoutInstance() {
        return this.context
            .layout.getLayoutInstance()
            .find((layout) => ['d3-force', 'd3-force-3d'].includes(layout?.id));
    }
    validate(event) {
        if (!this.context.layout)
            return false;
        // 未使用力导布局 / The force layout is not used
        if (!this.forceLayoutInstance) {
            console.warn('DragElementForce only works with d3-force or d3-force-3d layout');
            return false;
        }
        return super.validate(event);
    }
    async moveElement(ids, offset) {
        const layout = this.forceLayoutInstance;
        this.context.graph.getNodeData(ids).forEach((element, index) => {
            const { x = 0, y = 0 } = element.style || {};
            layout.setFixedPosition(ids[index], [...add([+x, +y], offset)]);
        });
    }
    onDragStart(event) {
        this.enable = this.validate(event);
        if (!this.enable)
            return;
        this.target = this.getSelectedNodeIDs([event.target.id]);
        this.hideEdge();
        this.context.graph.frontElement(this.target);
        const layout = this.forceLayoutInstance;
        layout.simulation.alphaTarget(0.3).restart();
        this.context.graph.getNodeData(this.target).forEach((element) => {
            const { x = 0, y = 0 } = element.style || {};
            layout.setFixedPosition(idOf(element), [+x, +y]);
        });
    }
    onDrag(event) {
        if (!this.enable)
            return;
        const delta = this.getDelta(event);
        this.moveElement(this.target, delta);
    }
    onDragEnd() {
        const layout = this.forceLayoutInstance;
        layout.simulation.alphaTarget(0);
        this.context.graph.getNodeData(this.target).forEach((element) => {
            layout.setFixedPosition(idOf(element), [null, null, null]);
        });
    }
}
//# sourceMappingURL=drag-element-force.js.map