import { Path } from '@antv/g';
import { isBBoxIntersectPolygon } from '../utils/behaviors/lasso';
import { getAllElementState } from '../utils/behaviors/utils';
import { pointsToPath } from '../utils/path';
import { BrushSelect, DEFAULT_STYLE } from './brush-select';
const SHOW_PATH_ID = 'g6-lasso-select-path-id';
export class LassoSelect extends BrushSelect {
    static defaultOptions = {
        ...BrushSelect.defaultOptions,
        style: DEFAULT_STYLE,
    };
    points;
    pathShape;
    selectElementFn = isBBoxIntersectPolygon;
    constructor(context, options) {
        super(context, Object.assign({}, LassoSelect.defaultOptions, options));
        this.bindEvents();
    }
    pointerDown = async (event) => {
        if (!this.validate(event) || !this.isKeydown() || this.points)
            return;
        const { style, trigger } = this.options;
        const triggers = (Array.isArray(trigger) ? trigger : [trigger]);
        if (event.targetType !== 'canvas' && triggers.includes('drag'))
            return;
        const { canvas } = this.context;
        this.pathShape = new Path({
            id: SHOW_PATH_ID,
            style: {
                ...LassoSelect.defaultOptions.style,
                fill: style.color || DEFAULT_STYLE.color,
                ...style,
                pointerEvents: 'none',
            },
        });
        canvas.appendChild(this.pathShape);
        this.points = [[event.canvas.x, event.canvas.y]];
    };
    pointerMove = async (event) => {
        if (!this.points)
            return;
        const { immediately, mode } = this.options;
        const { element } = this.context;
        this.points.push([event.canvas.x, event.canvas.y]);
        this.pathShape?.setAttribute('path', pointsToPath(this.points));
        if (immediately && mode === 'default') {
            this.lassoUpdateElementState();
        }
        await element?.draw({ animation: false, silence: true });
    };
    pointerUp = async () => {
        if (!this.points)
            return;
        if (this.points.length < 2) {
            await this.clearLasso();
            return;
        }
        this.lassoUpdateElementState();
        await this.clearLasso();
    };
    clearSelected = () => {
        if (this.points)
            return;
        const { graph } = this.context;
        const selects = getAllElementState(graph, () => []);
        graph.setElementState(selects, this.options.animation);
    };
    lassoUpdateElementState = () => {
        if (!this.points || this.points?.length < 2)
            return;
        this.updateElementState(this.points);
    };
    clearLasso = async () => {
        this.pathShape?.remove();
        this.pathShape = undefined;
        this.points = undefined;
    };
}
//# sourceMappingURL=lasso-select.js.map