import { Circle as GCircle } from '@antv/g';
import { isEmpty } from '@antv/util';
import { getBBoxSize } from '../../utils/bbox';
import { getCircleCollapsedOrigin, getXYByCollapsedOrigin } from '../../utils/combo';
import { subStyleProps } from '../../utils/prefix';
import { parseSize } from '../../utils/size';
import { BaseCombo } from './base-combo';
export class CircleCombo extends BaseCombo {
    constructor(options) {
        super(options);
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', GCircle, this.getKeyStyle(attributes), container);
    }
    getKeyStyle(attributes) {
        const { collapsed } = attributes;
        const keyStyle = super.getKeyStyle(attributes);
        const collapsedStyle = subStyleProps(keyStyle, 'collapsed');
        const [width] = this.getKeySize(attributes);
        return {
            ...keyStyle,
            ...(collapsed && collapsedStyle),
            r: width / 2,
        };
    }
    getCollapsedKeySize(attributes) {
        const [collapsedWidth, collapsedHeight] = parseSize(attributes.collapsedSize);
        const collapsedR = Math.max(collapsedWidth, collapsedHeight) / 2;
        return [collapsedR * 2, collapsedR * 2, 0];
    }
    getExpandedKeySize(attributes) {
        if (!isEmpty(attributes.size)) {
            const [expandedWidth, expandedHeight] = parseSize(attributes.size);
            const expandedR = Math.sqrt(expandedWidth ** 2 + expandedHeight ** 2) / 2;
            return [expandedR * 2, expandedR * 2, 0];
        }
        const contentBBox = this.getContentBBox(attributes);
        const [width, height] = getBBoxSize(contentBBox);
        const expandedR = Math.sqrt(width ** 2 + height ** 2) / 2;
        return [expandedR * 2, expandedR * 2, 0];
    }
    getCollapsedOriginPosition(attributes) {
        return getXYByCollapsedOrigin(attributes.collapsedOrigin, this.getContentBBox(attributes).center, this.getCollapsedKeySize(attributes), this.getExpandedKeySize(attributes), getCircleCollapsedOrigin);
    }
}
//# sourceMappingURL=circle.js.map