import { deepMix } from '@antv/util';
import { getCubicPath, getCurveControlPoint, parseCurveOffset, parseCurvePosition } from '../../utils/edge';
import { BaseEdge } from './base-edge';
export class Cubic extends BaseEdge {
    static defaultStyleProps = {
        curvePosition: 0.5,
        curveOffset: 20,
    };
    constructor(options) {
        super(deepMix({}, { style: Cubic.defaultStyleProps }, options));
    }
    getKeyPath(attributes) {
        const [sourcePoint, targetPoint] = this.getEndpoints(attributes);
        const { controlPoints, curvePosition, curveOffset } = attributes;
        const actualControlPoints = this.getControlPoints(sourcePoint, targetPoint, parseCurvePosition(curvePosition), parseCurveOffset(curveOffset), controlPoints);
        return getCubicPath(sourcePoint, targetPoint, actualControlPoints);
    }
    getControlPoints(sourcePoint, targetPoint, curvePosition, curveOffset, controlPoints) {
        return controlPoints?.length === 2
            ? controlPoints
            : [
                getCurveControlPoint(sourcePoint, targetPoint, curvePosition[0], curveOffset[0]),
                getCurveControlPoint(sourcePoint, targetPoint, curvePosition[1], curveOffset[1]),
            ];
    }
}
//# sourceMappingURL=cubic.js.map