import { Circle as GCircle } from '@antv/g';
import { deepMix } from '@antv/util';
import { ICON_SIZE_RATIO } from '../../constants/element';
import { getEllipseIntersectPoint } from '../../utils/point';
import { BaseNode } from './base-node';
/**
 * Draw circle based on BaseNode, override drawKeyShape.
 */
export class Circle extends BaseNode {
    static defaultStyleProps = {
        size: 24,
    };
    constructor(options) {
        super(deepMix({}, { style: Circle.defaultStyleProps }, options));
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', GCircle, this.getKeyStyle(attributes), container);
    }
    getKeyStyle(attributes) {
        const keyStyle = super.getKeyStyle(attributes);
        return { ...keyStyle, r: Math.min(...this.getSize(attributes)) / 2 };
    }
    getIconStyle(attributes) {
        const style = super.getIconStyle(attributes);
        const { r } = this.getKeyStyle(attributes);
        const size = r * 2 * ICON_SIZE_RATIO;
        return style ? { width: size, height: size, ...style } : false;
    }
    getIntersectPoint(point) {
        const keyShapeBounds = this.getKey().getBounds();
        return getEllipseIntersectPoint(point, keyShapeBounds);
    }
}
//# sourceMappingURL=circle.js.map