import { Image as GImage, Rect as GRect } from '@antv/g';
import { deepMix } from '@antv/util';
import { ICON_SIZE_RATIO } from '../../constants/element';
import { subStyleProps } from '../../utils/prefix';
import { add } from '../../utils/vector';
import { BaseNode } from './base-node';
export class Image extends BaseNode {
    static defaultStyleProps = {
        size: 50,
    };
    constructor(options) {
        super(deepMix({}, { style: Image.defaultStyleProps }, options));
    }
    getKeyStyle(attributes) {
        const [width, height] = this.getSize(attributes);
        const keyStyle = super.getKeyStyle(attributes);
        return {
            ...keyStyle,
            width,
            height,
            anchor: [0.5, 0.5],
        };
    }
    getHaloStyle(attributes) {
        if (attributes.halo === false)
            return false;
        const { fill: keyStyleFill, stroke: keyStyleStroke, ...keyStyle } = this.getKeyStyle(attributes);
        const haloStyle = subStyleProps(this.getGraphicStyle(attributes), 'halo');
        const haloLineWidth = Number(haloStyle.lineWidth);
        const [width, height] = add(this.getSize(attributes), [haloLineWidth, haloLineWidth]);
        const fill = 'transparent';
        return { ...keyStyle, ...haloStyle, width, height, fill };
    }
    getIconStyle(attributes) {
        const style = super.getIconStyle(attributes);
        const [width, height] = this.getSize(attributes);
        return style
            ? {
                width: width * ICON_SIZE_RATIO,
                height: height * ICON_SIZE_RATIO,
                ...style,
            }
            : false;
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', GImage, this.getKeyStyle(attributes), container);
    }
    drawHaloShape(attributes, container) {
        this.upsert('halo', GRect, this.getHaloStyle(attributes), container);
    }
}
//# sourceMappingURL=image.js.map