import { Rect as GRect } from '@antv/g';
import { deepMix } from '@antv/util';
import { ICON_SIZE_RATIO } from '../../constants/element';
import { BaseNode } from './base-node';
/**
 * Draw Rect based on BaseNode, override drawKeyShape.
 */
export class Rect extends BaseNode {
    static defaultStyleProps = {
        size: [48, 24],
        anchor: [0.5, 0.5],
    };
    constructor(options) {
        super(deepMix({}, { style: Rect.defaultStyleProps }, options));
    }
    getKeyStyle(attributes) {
        const [width, height] = this.getSize(attributes);
        return {
            ...super.getKeyStyle(attributes),
            width,
            height,
        };
    }
    getIconStyle(attributes) {
        const style = super.getIconStyle(attributes);
        const { width, height } = this.getKeyStyle(attributes);
        return style
            ? {
                width: width * ICON_SIZE_RATIO,
                height: height * ICON_SIZE_RATIO,
                ...style,
            }
            : false;
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', GRect, this.getKeyStyle(attributes), container);
    }
}
//# sourceMappingURL=rect.js.map