import type { ID } from '@antv/graphlib';
import type { RuntimeContext } from '../../runtime/types';
import type { CallableValue } from '../../types';
import type { BasePluginOptions } from '../base-plugin';
import { BasePlugin } from '../base-plugin';
import type { HullStyleProps } from './shape';
export interface HullOptions extends BasePluginOptions, HullStyleProps {
    /**
     * <zh/> Hull 内的元素
     * <en/> Elements in Hull
     */
    members?: ID[];
    /**
     * <zh/> 凹度，数值越大凹度越小；默认为 Infinity 代表为 Convex Hull
     * <en/> Concavity. Default is Infinity, which means Convex Hull
     */
    concavity?: number;
    /**
     * <zh/> 内边距，默认为 10
     * <en/> Padding, default is 10
     */
    padding?: number;
    /**
     * <zh/> 拐角类型，目前支持 'rounded'、'smooth' 和 'sharp'
     * <en/> Corner type, currently supports 'rounded', 'smooth' and 'sharp'
     */
    corner?: 'rounded' | 'smooth' | 'sharp';
}
export declare class Hull extends BasePlugin<HullOptions> {
    private shape;
    /**
     * <zh/> 在 Hull 上的元素
     * <en/> Element Ids on Hull
     */
    private hullMemberIds;
    /**
     * <zh/> Hull 绘制路径
     * <en/> Hull path
     */
    private path;
    /**
     * <zh> 是否初次渲染完成
     * <en> Whether the first rendering is completed
     */
    private firstRender;
    static defaultOptions: Partial<HullOptions>;
    constructor(context: RuntimeContext, options: HullOptions);
    private bindEvents;
    private getHullStyle;
    private drawHull;
    private updateHullPath;
    private getHullPath;
    private getPadding;
    addMembers(members: ID | ID[]): void;
    removeMembers(members: ID | ID[]): void;
    updateMembers(members: CallableValue<ID[]>): void;
    updateOptions(options: CallableValue<HullOptions>): void;
    destroy(): void;
}
