import { Path } from '@antv/g';
import { deepMix } from '@antv/util';
import { BaseShape, Label } from '../../elements/shapes';
import { getPolygonTextStyleByPlacement } from '../../utils/polygon';
import { subStyleProps } from '../../utils/prefix';
import { getWordWrapWidthByBox } from '../../utils/text';
export class Hull extends BaseShape {
    static defaultStyleProps = {
        label: true,
        labelPlacement: 'bottom',
        labelCloseToHull: true,
        labelAutoRotate: true,
        labelOffsetX: 0,
        labelOffsetY: 0,
    };
    constructor(options) {
        super(deepMix({}, { style: Hull.defaultStyleProps }, options));
    }
    getLabelStyle(attributes) {
        if (!attributes.label || !attributes.path || attributes.path.length === 0)
            return false;
        const { maxWidth, offsetX, offsetY, autoRotate, placement, closeToHull, ...labelStyle } = subStyleProps(this.getGraphicStyle(attributes), 'label');
        const contour = this.shapeMap.contour;
        const contourBounds = contour?.getRenderBounds();
        return Object.assign(getPolygonTextStyleByPlacement(contourBounds, placement, offsetX, offsetY, closeToHull, attributes.path, autoRotate), { wordWrapWidth: getWordWrapWidthByBox(contourBounds, maxWidth) }, labelStyle);
    }
    getContourStyle(attributes) {
        return this.getGraphicStyle(attributes);
    }
    render(attributes, container) {
        this.upsert('contour', Path, this.getContourStyle(attributes), container);
        this.upsert('label', Label, this.getLabelStyle(attributes), container);
    }
}
//# sourceMappingURL=shape.js.map