import type EventEmitter from '@antv/event-emitter';
import type { RuntimeContext } from '../../runtime/types';
import type { IEvent } from '../../types';
import type { ExtensionOptions, LooselyExtensionOption, STDExtensionOption } from './types';
export declare abstract class ExtensionController<Extension extends BaseExtension<LooselyExtensionOption>> {
    protected context: RuntimeContext;
    protected extensions: STDExtensionOption[];
    protected extensionMap: Record<string, Extension>;
    abstract category: 'plugin' | 'behavior' | 'transform';
    constructor(context: RuntimeContext);
    setExtensions(extensions: ExtensionOptions): void;
    protected createExtension(extension: STDExtensionOption): void;
    protected createExtensions(extensions: STDExtensionOption[]): void;
    protected updateExtension(extension: STDExtensionOption): void;
    protected updateExtensions(extensions: STDExtensionOption[]): void;
    protected destroyExtension(key: string): void;
    protected destroyExtensions(extensions: STDExtensionOption[]): void;
    destroy(): void;
}
/**
 * <zh/> 模块实例基类
 *
 * <en/> Base class for extension instance
 */
export declare class BaseExtension<T extends LooselyExtensionOption> {
    protected context: RuntimeContext;
    protected options: Required<T>;
    protected events: [EventEmitter | HTMLElement, string, (event: IEvent) => void][];
    destroyed: boolean;
    constructor(context: RuntimeContext, options: T);
    update(options: Partial<T>): void;
    destroy(): void;
}
