import { Graph as Graphlib } from '@antv/graphlib';
import type { Layout, LayoutMapping } from '@antv/layout';
import type { EdgeData, NodeData } from '../spec';
import type { STDLayoutOptions } from '../spec/layout';
import type { RuntimeContext } from './types';
type LayoutGraphlibModel = Graphlib<Required<NodeData>['style'], Required<EdgeData>['style']>;
export declare class LayoutController {
    private context;
    private supervisor?;
    private instance?;
    private instances;
    private animationResult?;
    private get presetOptions();
    private get options();
    constructor(context: RuntimeContext);
    getLayoutInstance(): Layout<unknown>[];
    getLayoutInstance(index: number): Layout<unknown>;
    layout(): Promise<void>;
    stepLayout(model: LayoutGraphlibModel, options: STDLayoutOptions, index: number): Promise<LayoutMapping>;
    private graphLayout;
    private treeLayout;
    stopLayout(): void;
    /**
     * <zh/> 获取参与布局的数据模型
     *
     * <en/> Get the data model involved in the layout
     * @param options - <zh/> 布局配置项 | <en/> Layout options
     * @returns <zh/> 布局数据 | <en/> Layout data
     */
    getLayoutDataModel(options: STDLayoutOptions): LayoutGraphlibModel;
    /**
     * <zh/> 创建布局实例
     *
     * <en/> Create layout instance
     * @param model - <zh/> 布局数据 | <en/> Layout data
     * @param options - <zh/> 布局配置项 | <en/> Layout options
     * @returns <zh/> 布局对象 | <en/> Layout object
     */
    private initGraphLayout;
    private updateElementPosition;
    destroy(): void;
}
export {};
