import type { BaseComboStyleProps } from '../elements/combos/base-combo';
import type { Point, Position, Size } from '../types';
/**
 * <zh/> 获取矩形 Combo 收起时原点的相对位置
 *
 * <en/> Get the relative position of the origin when Rect Combo is collapsed
 * @param collapsedOrigin - <zh/> 收起时的原点 | <en/> origin when collapsed
 * @param collapsedSize - <zh/> 收起尺寸 | <en/> collapsed size
 * @param expandedSize - <zh/> 展开尺寸 | <en/> expanded size
 * @returns <zh/> 收起时的原点 | <en/> origin when collapsed
 */
export declare function getRectCollapsedOrigin(collapsedOrigin: BaseComboStyleProps['collapsedOrigin'], collapsedSize: Size, expandedSize: Size): Position;
/**
 * <zh/> 获取圆形 Combo 收起时原点的相对位置
 *
 * <en/> Get the relative position of the origin when Circle Combo is collapsed
 * @param collapsedOrigin - <zh/> 收起时的原点 | <en/> origin when collapsed
 * @param collapsedSize - <zh/> 收起尺寸 | <en/> collapsed size
 * @param expandedSize - <zh/> 展开尺寸 | <en/> expanded size
 * @returns <zh/> 收起时的原点 | <en/> origin when collapsed
 */
export declare function getCircleCollapsedOrigin(collapsedOrigin: BaseComboStyleProps['collapsedOrigin'], collapsedSize: Size, expandedSize: Size): Position;
/**
 * <zh/> 计算 Combo 收起时原点的实际位置
 *
 * <en/> Calculate the actual position of the origin after the Combo is collapsed
 * @param collapsedOrigin - <zh/> 收起时的原点 | <en/> origin when collapsed
 * @param center - <zh/> 中心点 | <en/> center
 * @param collapsedSize - <zh/> 折叠尺寸 | <en/> folding size
 * @param expandedSize - <zh/> 展开尺寸 | <en/> expanded size
 * @param getCollapsedOrigin - <zh/> 获取原点相对位置的函数 | <en/> function to get the relative position of the origin
 * @returns <zh/> 原点实际位置 | <en/> actual position of the origin
 */
export declare function getXYByCollapsedOrigin(collapsedOrigin: BaseComboStyleProps['collapsedOrigin'], center: Point, collapsedSize: Size, expandedSize: Size, getCollapsedOrigin?: (collapsedOrigin: BaseComboStyleProps['collapsedOrigin'], collapsedSize: Size, expandedSize: Size) => Position): Position;
