import { Shortcut } from '../utils/shortcut';
import { BaseBehavior } from './base-behavior';
import type { ID } from '@antv/graphlib';
import type { Graph } from '../runtime/graph';
import type { RuntimeContext } from '../runtime/types';
import type { NodeStyle } from '../spec/element/node';
import type { ElementType, IPointerEvent, Points, State } from '../types';
import type { ShortcutKey } from '../utils/shortcut';
import type { BaseBehaviorOptions } from './base-behavior';
type SELECT_MODE = 'union' | 'intersect' | 'diff' | 'default';
export type States = Record<ID, State | State[]>;
export interface BrushSelectOptions extends BaseBehaviorOptions {
    /**
     * <zh/> 是否启用框选功能
     *
     * <en/> Whether to enable Brush select element function.
     */
    enable?: boolean | ((event: IPointerEvent) => boolean);
    /**
     * <zh/> 可框选的元素类型
     *
     * <en/> Enable Elements type.
     */
    enableElements?: ElementType[];
    /**
     * <zh/> 是否启用动画
     *
     * <en/> Whether to enable animation.
     */
    animation?: boolean;
    /**
     * <zh/> 交互配置 按键拖拽 或 直接拖拽
     *
     * <en/> Trigger click or drag.
     */
    trigger?: ShortcutKey;
    /**
     * <zh/> 框选选中模式
     * union : 选中元素添加 state 状态
     * intersect : 进一步筛选已经 state 开启的元素
     * diff : 反转选中元素的 state 状态
     * default : 选中元素添加 state 状态, 其他元素 state 关闭
     *
     * <en/> Box Select Select the mode.
     * union : Select element add state.
     * intersect : Further filter the elements that are already state enabled.
     * diff : Inverts the state of the selected element.
     * default : Check element state to turn on and other elements state to turn off.
     */
    mode?: SELECT_MODE;
    /**
     * <zh/> 选中 state 状态
     *
     * <en/> Check state status.
     */
    state?: 'selected' | 'active';
    /**
     * <zh/> 及时框选, 在框选模式为 default 时，才能使用
     *
     * <en/> Timely screening.
     */
    immediately?: boolean;
    /**
     * <zh/> 框选 框样式
     *
     * <en/> Timely screening.
     */
    style?: NodeStyle;
    /**
     * <zh/> 框选元素状态回调。
     *
     * <en/> Callback when brush select elements.
     */
    onSelect?: (states: States) => States;
}
export declare const DEFAULT_STYLE: {
    lineWidth: number;
    color: string;
    stroke: string;
    fillOpacity: number;
    zIndex: number;
};
export declare class BrushSelect<T extends BaseBehaviorOptions = BrushSelectOptions> extends BaseBehavior<T> {
    static defaultOptions: Partial<BrushSelectOptions>;
    private startPoint?;
    private endPoint?;
    private rectShape?;
    shortcut?: Shortcut;
    selectElementFn: (graph: Graph, id: ID, points: Points) => boolean;
    constructor(context: RuntimeContext, options: T);
    pointerDown: (event: IPointerEvent) => Promise<void>;
    pointerMove: (event: IPointerEvent) => Promise<void>;
    pointerUp: (event: IPointerEvent) => Promise<void>;
    clearSelected: () => void;
    updateElementState: (points: Points) => void;
    private clearBrush;
    getPointsSelectIds: (graph: Graph, points: Points, itemTypes: ElementType[]) => ID[];
    isKeydown(): boolean | undefined;
    validate(event: IPointerEvent): any;
    bindEvents(): void;
    unbindEvents(): void;
    destroy(): void;
}
export {};
