"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CollapseExpand = void 0;
const util_1 = require("@antv/util");
const constants_1 = require("../constants");
const element_1 = require("../utils/element");
const base_behavior_1 = require("./base-behavior");
class CollapseExpand extends base_behavior_1.BaseBehavior {
    static defaultOptions = {
        enable: true,
        animation: true,
    };
    constructor(context, options) {
        super(context, Object.assign({}, CollapseExpand.defaultOptions, options));
        this.bindEvents();
    }
    bindEvents() {
        const { graph } = this.context;
        this.unbindEvents();
        graph.on(`combo:${constants_1.CommonEvent.DBLCLICK}`, this.onCollapseExpand);
    }
    unbindEvents() {
        const { graph } = this.context;
        graph.off(`combo:${constants_1.CommonEvent.DBLCLICK}`, this.onCollapseExpand);
    }
    onCollapseExpand = async (event) => {
        if (!this.validate(event))
            return;
        const { target } = event;
        if (!(0, element_1.isElement)(target))
            return;
        const id = target.id;
        const { model, graph } = this.context;
        const data = model.getComboData([id])[0];
        if (!data)
            return false;
        const { onCollapse, onExpand, animation } = this.options;
        const isCollapse = data.style?.collapsed;
        if (isCollapse) {
            await graph.expand(id, animation);
            onExpand?.(id);
        }
        else {
            await graph.collapse(id, animation);
            onCollapse?.(id);
        }
    };
    validate(event) {
        if (this.destroyed)
            return false;
        const { enable } = this.options;
        if ((0, util_1.isFunction)(enable))
            return enable(event);
        return !!enable;
    }
    destroy() {
        this.unbindEvents();
        super.destroy();
    }
}
exports.CollapseExpand = CollapseExpand;
//# sourceMappingURL=collapse-expand.js.map