import type { RuntimeContext } from '../runtime/types';
import type { IKeyboardEvent, IPointerEvent, Vector2, ViewportAnimationEffectTiming } from '../types';
import type { ShortcutKey } from '../utils/shortcut';
import type { BaseBehaviorOptions } from './base-behavior';
import { BaseBehavior } from './base-behavior';
export interface DragCanvasOptions extends BaseBehaviorOptions {
    /**
     * <zh/> 是否启用拖拽动画，仅在使用按键移动时有效
     *
     * <en/> Whether to enable the animation of dragging, only valid when using key movement
     */
    animation?: ViewportAnimationEffectTiming;
    /**
     * <zh/> 是否启用拖拽画布的功能
     *
     * <en/> Whether to enable the function of dragging the canvas
     */
    enable?: boolean | ((event: IPointerEvent | IKeyboardEvent) => boolean);
    /**
     * <zh/> 触发拖拽的方式，默认使用指针按下拖拽
     *
     * <en/> The way to trigger dragging, default to dragging with the pointer pressed
     */
    trigger?: CombinationKey;
    /**
     * <zh/> 触发一次按键移动的距离
     *
     * <en/> The distance of a single key movement
     */
    sensitivity?: number;
    /**
     * <zh/> 完成拖拽时的回调
     *
     * <en/> Callback when dragging is completed
     */
    onFinish?: () => void;
}
type CombinationKey = {
    up: ShortcutKey;
    down: ShortcutKey;
    left: ShortcutKey;
    right: ShortcutKey;
};
export declare class DragCanvas extends BaseBehavior<DragCanvasOptions> {
    static defaultOptions: Partial<DragCanvasOptions>;
    private shortcut;
    private defaultCursor;
    constructor(context: RuntimeContext, options: DragCanvasOptions);
    private bindEvents;
    private onDrag;
    private onTranslate;
    protected translate(offset: Vector2, animation?: ViewportAnimationEffectTiming): Promise<void>;
    private validate;
    destroy(): void;
}
export {};
