"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DragCanvas = void 0;
const util_1 = require("@antv/util");
const constants_1 = require("../constants");
const shortcut_1 = require("../utils/shortcut");
const vector_1 = require("../utils/vector");
const base_behavior_1 = require("./base-behavior");
class DragCanvas extends base_behavior_1.BaseBehavior {
    static defaultOptions = {
        enable: true,
        sensitivity: 10,
    };
    shortcut;
    defaultCursor;
    constructor(context, options) {
        super(context, Object.assign({}, DragCanvas.defaultOptions, options));
        this.shortcut = new shortcut_1.Shortcut(context.graph);
        this.bindEvents();
        this.defaultCursor = this.context.canvas.getConfig().cursor || 'default';
        context.canvas.setCursor('grab');
    }
    bindEvents() {
        const { trigger } = this.options;
        this.shortcut.unbindAll();
        const { graph } = this.context;
        if ((0, util_1.isObject)(trigger)) {
            graph.off(constants_1.CanvasEvent.DRAG, this.onDrag);
            const { up = [], down = [], left = [], right = [] } = trigger;
            this.shortcut.bind(up, (event) => this.onTranslate([0, 1], event));
            this.shortcut.bind(down, (event) => this.onTranslate([0, -1], event));
            this.shortcut.bind(left, (event) => this.onTranslate([1, 0], event));
            this.shortcut.bind(right, (event) => this.onTranslate([-1, 0], event));
        }
        else {
            graph.on(constants_1.CanvasEvent.DRAG, this.onDrag);
        }
    }
    onDrag = (event) => {
        if (!this.validate(event))
            return;
        if (event.targetType === 'canvas') {
            this.translate([event.movement.x, event.movement.y], false);
            this.options.onFinish?.();
        }
    };
    async onTranslate(value, event) {
        if (!this.validate(event))
            return;
        const { sensitivity } = this.options;
        const delta = sensitivity * -1;
        await this.translate((0, vector_1.multiply)(value, delta), this.options.animation);
        this.options.onFinish?.();
    }
    async translate(offset, animation) {
        await this.context.graph.translateBy(offset, animation);
    }
    validate(event) {
        if (this.destroyed)
            return false;
        const { enable } = this.options;
        if ((0, util_1.isFunction)(enable))
            return enable(event);
        return !!enable;
    }
    destroy() {
        this.shortcut.destroy();
        this.context.canvas.setCursor(this.defaultCursor);
        super.destroy();
    }
}
exports.DragCanvas = DragCanvas;
//# sourceMappingURL=drag-canvas.js.map