"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FocusElement = void 0;
const util_1 = require("@antv/util");
const constants_1 = require("../constants");
const base_behavior_1 = require("./base-behavior");
const FOCUS_ELEMENT_TYPES = ['node', 'combo'];
class FocusElement extends base_behavior_1.BaseBehavior {
    static defaultOptions = {
        animation: {
            easing: 'ease-in',
            duration: 500,
        },
        enable: true,
    };
    constructor(context, options) {
        super(context, Object.assign({}, FocusElement.defaultOptions, options));
        this.bindEvents();
    }
    bindEvents() {
        const { graph } = this.context;
        this.unbindEvents();
        FOCUS_ELEMENT_TYPES.forEach((type) => {
            graph.on(`${type}:${constants_1.CommonEvent.CLICK}`, this.clickFocusElement);
        });
    }
    getSelectedNodeIDs(currTarget) {
        return Array.from(new Set(this.context.graph
            .getElementDataByState('node', this.options.state)
            .map((node) => node.id)
            .concat(currTarget)));
    }
    clickFocusElement = async (event) => {
        if (!this.validate(event))
            return;
        const { animation } = this.options;
        const { graph } = this.context;
        const id = this.getSelectedNodeIDs([event.target.id]);
        await graph.focusElement(id, animation);
    };
    validate(event) {
        if (this.destroyed)
            return false;
        const { enable } = this.options;
        if ((0, util_1.isFunction)(enable))
            return enable(event);
        return !!enable;
    }
    unbindEvents() {
        const { graph } = this.context;
        FOCUS_ELEMENT_TYPES.forEach((type) => {
            graph.off(`${type}:${constants_1.CommonEvent.CLICK}`, this.clickFocusElement);
        });
    }
    destroy() {
        this.unbindEvents();
        super.destroy();
    }
}
exports.FocusElement = FocusElement;
//# sourceMappingURL=focus-element.js.map