"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LassoSelect = void 0;
const g_1 = require("@antv/g");
const lasso_1 = require("../utils/behaviors/lasso");
const utils_1 = require("../utils/behaviors/utils");
const path_1 = require("../utils/path");
const brush_select_1 = require("./brush-select");
const SHOW_PATH_ID = 'g6-lasso-select-path-id';
class LassoSelect extends brush_select_1.BrushSelect {
    static defaultOptions = {
        ...brush_select_1.BrushSelect.defaultOptions,
        style: brush_select_1.DEFAULT_STYLE,
    };
    points;
    pathShape;
    selectElementFn = lasso_1.isBBoxIntersectPolygon;
    constructor(context, options) {
        super(context, Object.assign({}, LassoSelect.defaultOptions, options));
        this.bindEvents();
    }
    pointerDown = async (event) => {
        if (!this.validate(event) || !this.isKeydown() || this.points)
            return;
        const { style, trigger } = this.options;
        const triggers = (Array.isArray(trigger) ? trigger : [trigger]);
        if (event.targetType !== 'canvas' && triggers.includes('drag'))
            return;
        const { canvas } = this.context;
        this.pathShape = new g_1.Path({
            id: SHOW_PATH_ID,
            style: {
                ...LassoSelect.defaultOptions.style,
                fill: style.color || brush_select_1.DEFAULT_STYLE.color,
                ...style,
                pointerEvents: 'none',
            },
        });
        canvas.appendChild(this.pathShape);
        this.points = [[event.canvas.x, event.canvas.y]];
    };
    pointerMove = async (event) => {
        if (!this.points)
            return;
        const { immediately, mode } = this.options;
        const { element } = this.context;
        this.points.push([event.canvas.x, event.canvas.y]);
        this.pathShape?.setAttribute('path', (0, path_1.pointsToPath)(this.points));
        if (immediately && mode === 'default') {
            this.lassoUpdateElementState();
        }
        await element?.draw({ animation: false, silence: true });
    };
    pointerUp = async () => {
        if (!this.points)
            return;
        if (this.points.length < 2) {
            await this.clearLasso();
            return;
        }
        this.lassoUpdateElementState();
        await this.clearLasso();
    };
    clearSelected = () => {
        if (this.points)
            return;
        const { graph } = this.context;
        const selects = (0, utils_1.getAllElementState)(graph, () => []);
        graph.setElementState(selects, this.options.animation);
    };
    lassoUpdateElementState = () => {
        if (!this.points || this.points?.length < 2)
            return;
        this.updateElementState(this.points);
    };
    clearLasso = async () => {
        this.pathShape?.remove();
        this.pathShape = undefined;
        this.points = undefined;
    };
}
exports.LassoSelect = LassoSelect;
//# sourceMappingURL=lasso-select.js.map