"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZoomCanvas = void 0;
const util_1 = require("@antv/util");
const constants_1 = require("../constants");
const point_1 = require("../utils/point");
const shortcut_1 = require("../utils/shortcut");
const base_behavior_1 = require("./base-behavior");
class ZoomCanvas extends base_behavior_1.BaseBehavior {
    static defaultOptions = {
        animation: { duration: 200 },
        enable: true,
        sensitivity: 1,
        trigger: [],
    };
    shortcut;
    constructor(context, options) {
        super(context, Object.assign({}, ZoomCanvas.defaultOptions, options));
        this.shortcut = new shortcut_1.Shortcut(context.graph);
        this.bindEvents();
    }
    update(options) {
        super.update(options);
        this.bindEvents();
    }
    bindEvents() {
        const { trigger } = this.options;
        this.shortcut.unbindAll();
        if ((0, util_1.isArray)(trigger)) {
            this.preventDefault(constants_1.CanvasEvent.WHEEL);
            this.shortcut.bind([...trigger, constants_1.CanvasEvent.WHEEL], (event) => {
                const { deltaX, deltaY } = event;
                this.zoom(-(deltaY ?? deltaX), event, false);
            });
        }
        if ((0, util_1.isObject)(trigger)) {
            const { zoomIn = [], zoomOut = [], reset = [] } = trigger;
            this.shortcut.bind(zoomIn, (event) => this.zoom(10, event, this.options.animation));
            this.shortcut.bind(zoomOut, (event) => this.zoom(-10, event, this.options.animation));
            this.shortcut.bind(reset, this.onReset);
        }
    }
    /**
     * <zh/> 缩放画布
     *
     * <en/> Zoom canvas
     * @param value - <zh/> 缩放值， > 0 放大， < 0 缩小 | <en/> Zoom value, > 0 zoom in, < 0 zoom out
     * @param event - <zh/> 事件对象 | <en/> Event object
     * @param animation - <zh/> 缩放动画配置 | <en/> Zoom animation configuration
     */
    zoom = async (value, event, animation) => {
        if (!this.validate(event))
            return;
        const { graph } = this.context;
        let origin;
        if ('viewport' in event) {
            origin = (0, point_1.parsePoint)(event.viewport);
        }
        const { sensitivity, onFinish } = this.options;
        const ratio = 1 + ((0, util_1.clamp)(value, -50, 50) * sensitivity) / 100;
        const zoom = graph.getZoom();
        await graph.zoomTo(zoom * ratio, animation, origin);
        onFinish?.();
    };
    onReset = async () => {
        await this.context.graph.zoomTo(1, this.options.animation);
    };
    validate(event) {
        if (this.destroyed)
            return false;
        const { enable } = this.options;
        if ((0, util_1.isFunction)(enable))
            return enable(event);
        return !!enable;
    }
    preventDefault(eventName) {
        const listener = (e) => e.preventDefault();
        const container = this.context.canvas.getContainer();
        if (!container)
            return;
        container.addEventListener(eventName, listener);
    }
    destroy() {
        this.shortcut.destroy();
        super.destroy();
    }
}
exports.ZoomCanvas = ZoomCanvas;
//# sourceMappingURL=zoom-canvas.js.map