"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CircleCombo = void 0;
const g_1 = require("@antv/g");
const util_1 = require("@antv/util");
const bbox_1 = require("../../utils/bbox");
const combo_1 = require("../../utils/combo");
const prefix_1 = require("../../utils/prefix");
const size_1 = require("../../utils/size");
const base_combo_1 = require("./base-combo");
class CircleCombo extends base_combo_1.BaseCombo {
    constructor(options) {
        super(options);
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', g_1.Circle, this.getKeyStyle(attributes), container);
    }
    getKeyStyle(attributes) {
        const { collapsed } = attributes;
        const keyStyle = super.getKeyStyle(attributes);
        const collapsedStyle = (0, prefix_1.subStyleProps)(keyStyle, 'collapsed');
        const [width] = this.getKeySize(attributes);
        return {
            ...keyStyle,
            ...(collapsed && collapsedStyle),
            r: width / 2,
        };
    }
    getCollapsedKeySize(attributes) {
        const [collapsedWidth, collapsedHeight] = (0, size_1.parseSize)(attributes.collapsedSize);
        const collapsedR = Math.max(collapsedWidth, collapsedHeight) / 2;
        return [collapsedR * 2, collapsedR * 2, 0];
    }
    getExpandedKeySize(attributes) {
        if (!(0, util_1.isEmpty)(attributes.size)) {
            const [expandedWidth, expandedHeight] = (0, size_1.parseSize)(attributes.size);
            const expandedR = Math.sqrt(expandedWidth ** 2 + expandedHeight ** 2) / 2;
            return [expandedR * 2, expandedR * 2, 0];
        }
        const contentBBox = this.getContentBBox(attributes);
        const [width, height] = (0, bbox_1.getBBoxSize)(contentBBox);
        const expandedR = Math.sqrt(width ** 2 + height ** 2) / 2;
        return [expandedR * 2, expandedR * 2, 0];
    }
    getCollapsedOriginPosition(attributes) {
        return (0, combo_1.getXYByCollapsedOrigin)(attributes.collapsedOrigin, this.getContentBBox(attributes).center, this.getCollapsedKeySize(attributes), this.getExpandedKeySize(attributes), combo_1.getCircleCollapsedOrigin);
    }
}
exports.CircleCombo = CircleCombo;
//# sourceMappingURL=circle.js.map