"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseEdge = void 0;
const g_1 = require("@antv/g");
const util_1 = require("@antv/util");
const bbox_1 = require("../../utils/bbox");
const edge_1 = require("../../utils/edge");
const element_1 = require("../../utils/element");
const prefix_1 = require("../../utils/prefix");
const size_1 = require("../../utils/size");
const Symbol = __importStar(require("../../utils/symbol"));
const text_1 = require("../../utils/text");
const shapes_1 = require("../shapes");
const base_shape_1 = require("../shapes/base-shape");
class BaseEdge extends base_shape_1.BaseShape {
    type = 'edge';
    static defaultStyleProps = {
        isBillboard: true,
        label: true,
        labelAutoRotate: true,
        labelIsBillboard: true,
        labelMaxWidth: '80%',
        labelOffsetX: 4,
        labelOffsetY: 0,
        labelPlacement: 'center',
        labelTextBaseline: 'middle',
        labelWordWrap: false,
        halo: false,
        haloDroppable: false,
        haloLineDash: 0,
        haloLineWidth: 12,
        haloPointerEvents: 'none',
        haloStrokeOpacity: 0.25,
        haloZIndex: -1,
        startArrow: false,
        startArrowAnchor: '0.5 0.5',
        startArrowSize: 8,
        startArrowLineDash: 0,
        startArrowLineWidth: 1,
        startArrowTransformOrigin: 'center',
        startArrowType: 'triangle',
        endArrow: false,
        endArrowAnchor: '0.5 0.5',
        endArrowSize: 8,
        endArrowLineDash: 0,
        endArrowLineWidth: 1,
        endArrowTransformOrigin: 'center',
        endArrowType: 'triangle',
        loopPlacement: 'top',
        loopClockwise: true,
    };
    constructor(options) {
        super((0, util_1.deepMix)({}, { style: BaseEdge.defaultStyleProps }, options));
    }
    getKeyStyle(attributes) {
        const { sourceNode, targetNode, color, stroke, ...style } = this.getGraphicStyle(attributes);
        const path = (0, element_1.isSameNode)(sourceNode, targetNode) ? this.getLoopPath(attributes) : this.getKeyPath(attributes);
        return {
            path,
            ...(0, prefix_1.omitStyleProps)(style, ['halo', 'label', 'startArrow', 'endArrow']),
            stroke: color || stroke,
        };
    }
    getLoopPath(attributes) {
        const { sourceNode: node, sourcePort, targetPort } = attributes;
        const bbox = (0, bbox_1.getNodeBBox)(node);
        const defaultDist = Math.max((0, bbox_1.getBBoxWidth)(bbox), (0, bbox_1.getBBoxHeight)(bbox));
        const { placement, clockwise, dist = defaultDist, } = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), 'loop');
        return (0, edge_1.getCubicLoopPath)(node, placement, clockwise, dist, sourcePort, targetPort);
    }
    getEndpoints(attributes) {
        const { sourceNode, targetNode, sourcePort: sourcePortKey, targetPort: targetPortKey } = attributes;
        const [sourcePort, targetPort] = (0, element_1.findPorts)(sourceNode, targetNode, sourcePortKey, targetPortKey);
        const sourcePoint = (0, element_1.getConnectionPoint)(sourcePort || sourceNode, targetPort || targetNode);
        const targetPoint = (0, element_1.getConnectionPoint)(targetPort || targetNode, sourcePort || sourceNode);
        return [sourcePoint, targetPoint];
    }
    getHaloStyle(attributes) {
        if (attributes.halo === false)
            return false;
        const keyStyle = this.getKeyStyle(attributes);
        const haloStyle = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), 'halo');
        return { ...keyStyle, ...haloStyle };
    }
    getLabelStyle(attributes) {
        if (attributes.label === false || (0, util_1.isEmpty)(attributes.labelText))
            return false;
        const labelStyle = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), 'label');
        const { placement, offsetX, offsetY, autoRotate, maxWidth, ...restStyle } = labelStyle;
        const labelPositionStyle = (0, edge_1.getLabelPositionStyle)(this.shapeMap.key, placement, autoRotate, offsetX, offsetY);
        const bbox = this.shapeMap.key.getLocalBounds();
        const wordWrapWidth = (0, text_1.getWordWrapWidthByEnds)([bbox.min, bbox.max], maxWidth);
        return Object.assign({ wordWrapWidth }, labelPositionStyle, restStyle);
    }
    drawArrow(attributes, type) {
        const isStart = type === 'start';
        const arrowType = type === 'start' ? 'startArrow' : 'endArrow';
        const enable = attributes[arrowType];
        const keyShape = this.shapeMap.key;
        if (enable) {
            const arrowStyle = this.getArrowStyle(attributes, isStart);
            const Ctor = !(0, util_1.isEmpty)(arrowStyle.src) ? g_1.Image : g_1.Path;
            const [marker, markerOffset, arrowOffset] = isStart
                ? ['markerStart', 'markerStartOffset', 'startArrowOffset']
                : ['markerEnd', 'markerEndOffset', 'endArrowOffset'];
            const arrow = keyShape.style[marker];
            // update
            if (arrow)
                arrow.attr(arrowStyle);
            // create
            else
                keyShape.style[marker] = new Ctor({ style: arrowStyle });
            keyShape.style[markerOffset] = attributes[arrowOffset] || arrowStyle.width / 2 + +arrowStyle.lineWidth;
        }
        else {
            // destroy
            const marker = isStart ? 'markerStart' : 'markerEnd';
            keyShape.style[marker]?.destroy();
            keyShape.style[marker] = null;
        }
    }
    getArrowStyle(attributes, isStart) {
        const keyStyle = this.getKeyStyle(attributes);
        const arrowType = isStart ? 'startArrow' : 'endArrow';
        const { size, type, ...arrowStyle } = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), arrowType);
        const [width, height] = (0, size_1.parseSize)(size);
        const arrowFn = (0, util_1.isFunction)(type) ? type : Symbol[type] || Symbol.triangle;
        const path = arrowFn(width, height);
        return {
            ...keyStyle,
            width,
            height,
            ...(path && { path, fill: type === 'simple' ? '' : keyStyle.stroke }),
            ...arrowStyle,
        };
    }
    drawLabelShape(attributes, container) {
        this.upsert('label', shapes_1.Label, this.getLabelStyle(attributes), container);
    }
    drawHaloShape(attributes, container) {
        this.upsert('halo', g_1.Path, this.getHaloStyle(attributes), container);
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', g_1.Path, this.getKeyStyle(attributes), container);
    }
    render(attributes = this.parsedAttributes, container = this) {
        // 1. key shape
        const keyShape = this.drawKeyShape(attributes, container);
        if (!keyShape)
            return;
        // 2. arrows
        this.drawArrow(attributes, 'start');
        this.drawArrow(attributes, 'end');
        // 3. label
        this.drawLabelShape(attributes, container);
        // 4. halo
        this.drawHaloShape(attributes, container);
    }
    /**
     * <zh/> 在元素完成创建并执行完入场动画后调用
     *
     * <en/> Called after the element is created and the entrance animation is completed
     * @override
     */
    onCreate() { }
    /**
     * <zh/> 在元素更新并执行完过渡动画后调用
     *
     * <en/> Called after the element is updated and the transition animation is completed
     * @override
     */
    onUpdate() { }
    /**
     * <zh/> 在元素完成退场动画并销毁后调用
     *
     * <en/> Called after the element completes the exit animation and is destroyed
     * @override
     */
    onDestroy() { }
    animate(keyframes, options) {
        const result = super.animate(keyframes, options);
        if (result) {
            result.onframe = () => {
                this.drawLabelShape(this.parsedAttributes, this);
            };
        }
        return result;
    }
}
exports.BaseEdge = BaseEdge;
//# sourceMappingURL=base-edge.js.map