"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cubic = void 0;
const util_1 = require("@antv/util");
const edge_1 = require("../../utils/edge");
const base_edge_1 = require("./base-edge");
class Cubic extends base_edge_1.BaseEdge {
    static defaultStyleProps = {
        curvePosition: 0.5,
        curveOffset: 20,
    };
    constructor(options) {
        super((0, util_1.deepMix)({}, { style: Cubic.defaultStyleProps }, options));
    }
    getKeyPath(attributes) {
        const [sourcePoint, targetPoint] = this.getEndpoints(attributes);
        const { controlPoints, curvePosition, curveOffset } = attributes;
        const actualControlPoints = this.getControlPoints(sourcePoint, targetPoint, (0, edge_1.parseCurvePosition)(curvePosition), (0, edge_1.parseCurveOffset)(curveOffset), controlPoints);
        return (0, edge_1.getCubicPath)(sourcePoint, targetPoint, actualControlPoints);
    }
    getControlPoints(sourcePoint, targetPoint, curvePosition, curveOffset, controlPoints) {
        return controlPoints?.length === 2
            ? controlPoints
            : [
                (0, edge_1.getCurveControlPoint)(sourcePoint, targetPoint, curvePosition[0], curveOffset[0]),
                (0, edge_1.getCurveControlPoint)(sourcePoint, targetPoint, curvePosition[1], curveOffset[1]),
            ];
    }
}
exports.Cubic = Cubic;
//# sourceMappingURL=cubic.js.map