"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Image = void 0;
const g_1 = require("@antv/g");
const util_1 = require("@antv/util");
const element_1 = require("../../constants/element");
const prefix_1 = require("../../utils/prefix");
const vector_1 = require("../../utils/vector");
const base_node_1 = require("./base-node");
class Image extends base_node_1.BaseNode {
    static defaultStyleProps = {
        size: 50,
    };
    constructor(options) {
        super((0, util_1.deepMix)({}, { style: Image.defaultStyleProps }, options));
    }
    getKeyStyle(attributes) {
        const [width, height] = this.getSize(attributes);
        const keyStyle = super.getKeyStyle(attributes);
        return {
            ...keyStyle,
            width,
            height,
            anchor: [0.5, 0.5],
        };
    }
    getHaloStyle(attributes) {
        if (attributes.halo === false)
            return false;
        const { fill: keyStyleFill, stroke: keyStyleStroke, ...keyStyle } = this.getKeyStyle(attributes);
        const haloStyle = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), 'halo');
        const haloLineWidth = Number(haloStyle.lineWidth);
        const [width, height] = (0, vector_1.add)(this.getSize(attributes), [haloLineWidth, haloLineWidth]);
        const fill = 'transparent';
        return { ...keyStyle, ...haloStyle, width, height, fill };
    }
    getIconStyle(attributes) {
        const style = super.getIconStyle(attributes);
        const [width, height] = this.getSize(attributes);
        return style
            ? {
                width: width * element_1.ICON_SIZE_RATIO,
                height: height * element_1.ICON_SIZE_RATIO,
                ...style,
            }
            : false;
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', g_1.Image, this.getKeyStyle(attributes), container);
    }
    drawHaloShape(attributes, container) {
        this.upsert('halo', g_1.Rect, this.getHaloStyle(attributes), container);
    }
}
exports.Image = Image;
//# sourceMappingURL=image.js.map