"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rect = void 0;
const g_1 = require("@antv/g");
const util_1 = require("@antv/util");
const element_1 = require("../../constants/element");
const base_node_1 = require("./base-node");
/**
 * Draw Rect based on BaseNode, override drawKeyShape.
 */
class Rect extends base_node_1.BaseNode {
    static defaultStyleProps = {
        size: [48, 24],
        anchor: [0.5, 0.5],
    };
    constructor(options) {
        super((0, util_1.deepMix)({}, { style: Rect.defaultStyleProps }, options));
    }
    getKeyStyle(attributes) {
        const [width, height] = this.getSize(attributes);
        return {
            ...super.getKeyStyle(attributes),
            width,
            height,
        };
    }
    getIconStyle(attributes) {
        const style = super.getIconStyle(attributes);
        const { width, height } = this.getKeyStyle(attributes);
        return style
            ? {
                width: width * element_1.ICON_SIZE_RATIO,
                height: height * element_1.ICON_SIZE_RATIO,
                ...style,
            }
            : false;
    }
    drawKeyShape(attributes, container) {
        return this.upsert('key', g_1.Rect, this.getKeyStyle(attributes), container);
    }
}
exports.Rect = Rect;
//# sourceMappingURL=rect.js.map