"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hull = void 0;
const g_1 = require("@antv/g");
const util_1 = require("@antv/util");
const shapes_1 = require("../../elements/shapes");
const polygon_1 = require("../../utils/polygon");
const prefix_1 = require("../../utils/prefix");
const text_1 = require("../../utils/text");
class Hull extends shapes_1.BaseShape {
    static defaultStyleProps = {
        label: true,
        labelPlacement: 'bottom',
        labelCloseToHull: true,
        labelAutoRotate: true,
        labelOffsetX: 0,
        labelOffsetY: 0,
    };
    constructor(options) {
        super((0, util_1.deepMix)({}, { style: Hull.defaultStyleProps }, options));
    }
    getLabelStyle(attributes) {
        if (!attributes.label || !attributes.path || attributes.path.length === 0)
            return false;
        const { maxWidth, offsetX, offsetY, autoRotate, placement, closeToHull, ...labelStyle } = (0, prefix_1.subStyleProps)(this.getGraphicStyle(attributes), 'label');
        const contour = this.shapeMap.contour;
        const contourBounds = contour?.getRenderBounds();
        return Object.assign((0, polygon_1.getPolygonTextStyleByPlacement)(contourBounds, placement, offsetX, offsetY, closeToHull, attributes.path, autoRotate), { wordWrapWidth: (0, text_1.getWordWrapWidthByBox)(contourBounds, maxWidth) }, labelStyle);
    }
    getContourStyle(attributes) {
        return this.getGraphicStyle(attributes);
    }
    render(attributes, container) {
        this.upsert('contour', g_1.Path, this.getContourStyle(attributes), container);
        this.upsert('label', shapes_1.Label, this.getLabelStyle(attributes), container);
    }
}
exports.Hull = Hull;
//# sourceMappingURL=shape.js.map