"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BUILT_IN_EXTENSIONS = void 0;
const animations_1 = require("../animations");
const behaviors_1 = require("../behaviors");
const elements_1 = require("../elements");
const layouts_1 = require("../layouts");
const palettes_1 = require("../palettes");
const plugins_1 = require("../plugins");
const themes_1 = require("../themes");
const transforms_1 = require("../transforms");
/**
 * <zh/> 内置插件统一在这里注册。
 * <en/> Built-in extensions are registered here.
 */
exports.BUILT_IN_EXTENSIONS = {
    animation: {
        fade: animations_1.fade,
        translate: animations_1.translate,
        'combo-collapse-expand': animations_1.comboCollapseExpand,
    },
    behavior: {
        'zoom-canvas': behaviors_1.ZoomCanvas,
        'drag-canvas': behaviors_1.DragCanvas,
        'drag-element': behaviors_1.DragElement,
        'drag-element-force': behaviors_1.DragElementForce,
        'collapse-expand': behaviors_1.CollapseExpand,
        'click-element': behaviors_1.ClickElement,
        'hover-element': behaviors_1.HoverElement,
        'focus-element': behaviors_1.FocusElement,
        'create-edge': behaviors_1.CreateEdge,
        'brush-select': behaviors_1.BrushSelect,
        'lasso-select': behaviors_1.LassoSelect,
    },
    combo: {
        circle: elements_1.CircleCombo,
        rect: elements_1.RectCombo,
    },
    edge: {
        cubic: elements_1.Cubic,
        line: elements_1.Line,
        polyline: elements_1.Polyline,
        quadratic: elements_1.Quadratic,
        'cubic-horizontal': elements_1.CubicHorizontal,
        'cubic-vertical': elements_1.CubicVertical,
    },
    layout: {
        'antv-dagre': layouts_1.AntVDagreLayout,
        'combo-combined': layouts_1.ComboCombinedLayout,
        'compact-box': layouts_1.compactBox,
        'force-atlas2': layouts_1.ForceAtlas2Layout,
        circular: layouts_1.CircularLayout,
        concentric: layouts_1.ConcentricLayout,
        d3force: layouts_1.D3ForceLayout,
        'd3-force-3d': layouts_1.D3Force3DLayout,
        dagre: layouts_1.DagreLayout,
        dendrogram: layouts_1.dendrogram,
        force: layouts_1.ForceLayout,
        fruchterman: layouts_1.FruchtermanLayout,
        grid: layouts_1.GridLayout,
        indented: layouts_1.indented,
        mds: layouts_1.MDSLayout,
        mindmap: layouts_1.mindmap,
        radial: layouts_1.RadialLayout,
        random: layouts_1.RandomLayout,
    },
    node: {
        circle: elements_1.Circle,
        ellipse: elements_1.Ellipse,
        image: elements_1.Image,
        rect: elements_1.Rect,
        star: elements_1.Star,
        triangle: elements_1.Triangle,
        diamond: elements_1.Diamond,
        hexagon: elements_1.Hexagon,
    },
    palette: {
        spectral: palettes_1.spectral,
        tableau: palettes_1.tableau,
        oranges: palettes_1.oranges,
        greens: palettes_1.greens,
        blues: palettes_1.blues,
    },
    theme: {
        dark: themes_1.dark,
        light: themes_1.light,
    },
    plugin: {
        hull: plugins_1.Hull,
        'grid-line': plugins_1.GridLine,
        watermark: plugins_1.Watermark,
        tooltip: plugins_1.Tooltip,
        contextmenu: plugins_1.Contextmenu,
        toolbar: plugins_1.Toolbar,
        legend: plugins_1.Legend,
        history: plugins_1.History,
    },
    transform: {
        'update-related-edges': transforms_1.UpdateRelatedEdge,
        'arrange-draw-order': transforms_1.ArrangeDrawOrder,
        'collapse-expand-combo': transforms_1.CollapseExpandCombo,
        'process-parallel-edges': transforms_1.ProcessParallelEdges,
    },
};
//# sourceMappingURL=build-in.js.map