"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BehaviorController = void 0;
const constants_1 = require("../constants");
const extension_1 = require("../registry/extension");
const event_1 = require("../utils/event");
class BehaviorController extends extension_1.ExtensionController {
    /** <zh/> 当前事件的目标 | <en/> The current event target */
    currentTarget = null;
    category = 'behavior';
    constructor(context) {
        super(context);
        this.forwardEvents();
        this.setBehaviors(this.context.options.behaviors || []);
    }
    setBehaviors(behaviors) {
        this.setExtensions(behaviors);
    }
    forwardEvents() {
        const container = this.context.canvas.getContainer();
        if (container) {
            [constants_1.ContainerEvent.KEY_DOWN, constants_1.ContainerEvent.KEY_UP].forEach((name) => {
                container.addEventListener(name, this.forwardContainerEvents);
            });
        }
        const canvas = this.context.canvas.document;
        if (canvas) {
            [
                constants_1.CanvasEvent.CLICK,
                constants_1.CanvasEvent.DBLCLICK,
                constants_1.CanvasEvent.POINTER_OVER,
                constants_1.CanvasEvent.POINTER_LEAVE,
                constants_1.CanvasEvent.POINTER_ENTER,
                constants_1.CanvasEvent.POINTER_MOVE,
                constants_1.CanvasEvent.POINTER_OUT,
                constants_1.CanvasEvent.POINTER_DOWN,
                constants_1.CanvasEvent.POINTER_UP,
                constants_1.CanvasEvent.CONTEXT_MENU,
                constants_1.CanvasEvent.DRAG_START,
                constants_1.CanvasEvent.DRAG,
                constants_1.CanvasEvent.DRAG_END,
                constants_1.CanvasEvent.DRAG_ENTER,
                constants_1.CanvasEvent.DRAG_OVER,
                constants_1.CanvasEvent.DRAG_LEAVE,
                constants_1.CanvasEvent.DROP,
                constants_1.CanvasEvent.WHEEL,
            ].forEach((name) => {
                canvas.addEventListener(name, this.forwardCanvasEvents);
            });
        }
    }
    forwardCanvasEvents = (event) => {
        const { target: originalTarget } = event;
        const target = (0, event_1.eventTargetOf)(originalTarget);
        if (!target)
            return;
        const { graph, canvas } = this.context;
        const { type: targetType, element: targetElement } = target;
        const { type, detail, button } = event;
        const stdEvent = { ...event, target: targetElement, targetType, originalTarget };
        if (type === constants_1.CanvasEvent.POINTER_MOVE) {
            if (this.currentTarget !== targetElement) {
                if (this.currentTarget) {
                    graph.emit(`${targetType}:${constants_1.CanvasEvent.POINTER_LEAVE}`, { ...stdEvent, target: this.currentTarget });
                }
                if (targetElement) {
                    graph.emit(`${targetType}:${constants_1.CanvasEvent.POINTER_ENTER}`, stdEvent);
                }
            }
            this.currentTarget = targetElement;
        }
        // 非右键点击事件 / Click event except right click
        if (!(type === constants_1.CanvasEvent.CLICK && button === 2)) {
            graph.emit(`${targetType}:${type}`, stdEvent);
            graph.emit(type, stdEvent);
        }
        // 双击事件 / Double click event
        if (type === constants_1.CanvasEvent.CLICK && detail === 2) {
            graph.emit(`${targetType}:${constants_1.CanvasEvent.DBLCLICK}`, stdEvent);
            graph.emit(constants_1.CanvasEvent.DBLCLICK, stdEvent);
        }
        // 右键菜单 / Contextmenu
        if (type === constants_1.CanvasEvent.POINTER_DOWN && button === 2) {
            const contextMenuEvent = {
                ...stdEvent,
                preventDefault: () => {
                    canvas.getContainer()?.addEventListener(constants_1.CanvasEvent.CONTEXT_MENU, (e) => e.preventDefault(), {
                        once: true,
                    });
                },
            };
            graph.emit(`${targetType}:${constants_1.CanvasEvent.CONTEXT_MENU}`, contextMenuEvent);
            graph.emit(constants_1.CanvasEvent.CONTEXT_MENU, contextMenuEvent);
        }
    };
    forwardContainerEvents = (event) => {
        this.context.graph.emit(event.type, event);
    };
    destroy() {
        const container = this.context.canvas.getContainer();
        if (container) {
            [constants_1.ContainerEvent.KEY_DOWN, constants_1.ContainerEvent.KEY_UP].forEach((name) => {
                container.removeEventListener(name, this.forwardContainerEvents);
            });
        }
        this.context.canvas.document.removeAllEventListeners();
        super.destroy();
    }
}
exports.BehaviorController = BehaviorController;
//# sourceMappingURL=behavior.js.map