import type { DisplayObject, IAnimation } from '@antv/g';
import type { G6Spec } from '../spec';
import type { AnimatableTask, Keyframe } from '../types';
export declare function createAnimationsProxy(animations: IAnimation[]): IAnimation | null;
export declare function createAnimationsProxy(sourceAnimation: IAnimation, targetAnimations: IAnimation[]): IAnimation;
/**
 * <zh/> 预处理关键帧，过滤掉无用动画的属性
 *
 * <en/> Preprocess keyframes, filter out the properties of useless animations
 * @param keyframes - <zh/> 关键帧 | <en/> keyframes
 * @returns <zh/> 关键帧 | <en/> keyframes
 */
export declare function preprocessKeyframes(keyframes: Keyframe[]): Keyframe[];
/**
 * <zh/> 对图形执行动画
 *
 * <en/> Animate the shape
 * @param shape - <zh/> 待执行动画的图形 | <en/> the shape to be animated
 * @param keyframes - <zh/> 动画关键帧 | <en/> keyframes of the animation
 * @param options - <zh/> 动画配置项 | <en/> animation options
 * @returns <zh/> 动画对象 | <en/> animation object
 * @description
 * <zh/> 在设置 enableCSSParsing 为 false 后，复合图形无法继承父属性，因此对于一些需要继承父属性的动画，需要对所有子图形执行相同的动画
 *
 * <en/> After setting enableCSSParsing to false, the compound shape cannot inherit the parent attribute, so for some animations that need to inherit the parent attribute, the same animation needs to be performed on all child shapes
 */
export declare function executeAnimation<T extends DisplayObject>(shape: T, keyframes: Keyframe[], options: KeyframeAnimationOptions): IAnimation | null;
/**
 * <zh/> 获取属性的默认值
 *
 * <en/> Get default value of attribute
 * @param name - <zh/> 属性名 | <en/> Attribute name
 * @returns <zh/> 属性默认值 | <en/> Attribute default value
 * @description
 * <zh/> 执行动画过程中，一些属性没有显式指定属性值，但实际上在 G 中存在属性值，因此通过该方法获取其实际默认值
 *
 * <en/> During the animation, some attributes do not explicitly specify the attribute value, but in fact there is an attribute value in G, so use this method to get the actual default value
 */
export declare function inferDefaultValue(name: string): false | 1 | never[] | 0 | "visible" | undefined;
type Callbacks = {
    before?: () => void;
    beforeAnimate?: (result: IAnimation) => void;
    afterAnimate?: (result: IAnimation) => void;
    after?: () => void;
};
/**
 * <zh/> 执行动画前后的回调
 *
 * <en/> Callback before and after animation execution
 * @param animation - <zh/> 动画对象 | <en/> animation object
 * @param callbacks - <zh/> 回调函数 | <en/> callback function
 * @returns <zh/> 动画对象 | <en/> animation object
 */
export declare function withAnimationCallbacks(animation: IAnimation | null, callbacks: Callbacks): IAnimation | null;
/**
 * <zh/> 执行动画任务
 *
 * <en/> Execute animation tasks
 * @param tasks - <zh/> 动画任务 | <en/> animation task
 * @param callbacks - <zh/> 回调函数 | <en/> callback function
 * @returns <zh/> 动画对象 | <en/> animation object
 */
export declare function executeAnimatableTasks(tasks: AnimatableTask[], callbacks?: Callbacks): IAnimation | null;
/**
 * <zh/> 获取动画配置
 *
 * <en/> Get global animation configuration
 * @param options - <zh/> G6 配置项（用于获取全局动画配置） | <en/> G6 configuration(used to get global animation configuration)
 * @param localAnimation - <zh/> 局部动画配置 | <en/> local animation configuration
 * @returns <zh/> 动画配置 | <en/> animation configuration
 */
export declare function getAnimation(options: G6Spec, localAnimation: boolean | EffectTiming | undefined): false | EffectTiming;
export {};
