"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformEdgeState = exports.getAllElementState = void 0;
const util_1 = require("@antv/util");
/**
 * <zh/> 获取所有元素状态.
 *
 * <en/> Gets all element states.
 * @param graph Graph
 * @param callback (id: ID, state: string[]) => string[]
 * @returns States
 */
const getAllElementState = (graph, callback) => {
    const allElementState = {};
    const datas = graph.getData();
    Object.values(datas).forEach((data) => {
        data.map((d) => {
            const state = graph.getElementState(d.id);
            allElementState[d.id] = (0, util_1.isFunction)(callback) ? callback(d.id, state) : state;
        });
    });
    return allElementState;
};
exports.getAllElementState = getAllElementState;
/**
 * <zh/> 转化 edge 状态.
 *
 * <en/> Example Transform the edge state.
 * @param graph Graph
 * @param states States
 * @param state 'active' | 'selected'
 */
const transformEdgeState = (graph, states, state) => {
    const edgeData = graph.getEdgeData();
    edgeData.forEach(({ id, target, source }) => {
        if (!id)
            return;
        if (states[target].includes(state) && states[source].includes(state)) {
            states[id] = [state];
        }
        else {
            states[id] = [];
        }
    });
};
exports.transformEdgeState = transformEdgeState;
//# sourceMappingURL=utils.js.map