"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTreeStructure = exports.toG6Data = exports.toGraphlibData = void 0;
const constants_1 = require("../constants");
const id_1 = require("./id");
const is_1 = require("./is");
/**
 * <zh/> 将 NodeData、EdgeData、ComboData 转换为 graphlib 的数据结构
 *
 * <en/> Transform NodeData, EdgeData, ComboData to graphlib data structure
 * @param data - <zh/> 节点、边、combo 数据 | <en/> node, combo data
 * @returns <zh/> graphlib 数据 | <en/> graphlib data
 */
function toGraphlibData(data) {
    const { id = (0, id_1.idOf)(data), style, data: customData, ...rest } = data;
    const _data = { ...data, style: { ...style }, data: { ...customData } };
    if ((0, is_1.isEdgeData)(data))
        return { id, data: _data, ...rest };
    return { id, data: _data };
}
exports.toGraphlibData = toGraphlibData;
/**
 * <zh/> 将 Node、Edge、Combo 转换为 G6 的数据结构
 *
 * <en/> Transform Node, Edge, Combo to G6 data structure
 * @param data - <zh/> graphlib 节点、边、Combo 数据 | <en/> graphlib node, edge, combo data
 * @returns <zh/> G6 数据 | <en/> G6 data
 */
function toG6Data(data) {
    return data.data;
}
exports.toG6Data = toG6Data;
/**
 * <zh/> 创建树形结构
 *
 * <en/> Create tree structure
 * @param model - <zh/> 数据模型 | <en/> data model
 */
function createTreeStructure(model) {
    if (model.hasTreeStructure(constants_1.TREE_KEY))
        return;
    model.attachTreeStructure(constants_1.TREE_KEY);
    const edges = model.getAllEdges();
    for (const edge of edges) {
        const { source, target } = edge;
        model.setParent(target, source, constants_1.TREE_KEY);
    }
}
exports.createTreeStructure = createTreeStructure;
//# sourceMappingURL=graphlib.js.map