"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.idsOf = exports.parentIdOf = exports.idOf = void 0;
const util_1 = require("@antv/util");
const is_1 = require("./is");
/**
 * <zh/> 获取节点/边/Combo 的 ID
 *
 * <en/> get the id of node/edge/combo
 * @param data - <zh/> 节点/边/Combo 的数据 | <en/> data of node/edge/combo
 * @returns <zh/> 节点/边/Combo 的 ID | <en/> ID of node/edge/combo
 */
function idOf(data) {
    if ((0, util_1.isString)(data.id) || (0, util_1.isNumber)(data.id))
        return data.id;
    if ((0, is_1.isEdgeData)(data))
        return `${data.source}-${data.target}`;
    throw new Error('The data does not have available id.');
}
exports.idOf = idOf;
/**
 * <zh/> 获取节点/Combo 的父节点 ID
 *
 * <en/> get the parent id of node/combo
 * @param data - <zh/> 节点/Combo 的数据 | <en/> data of node/combo
 * @returns <zh/> 节点/Combo 的父节点 ID | <en/> parent id of node/combo
 */
function parentIdOf(data) {
    return data.style?.parentId;
}
exports.parentIdOf = parentIdOf;
/**
 * <zh/> 获取图数据中所有节点/边/Combo 的 ID
 *
 * <en/> Get the IDs of all nodes/edges/combos in the graph data
 * @param data - <zh/> 图数据 | <en/> graph data
 * @param flat - <zh/> 是否扁平化返回 | <en/> Whether to return flat
 * @returns - <zh/> 返回元素 ID 数组 | <en/> Returns an array of element IDs
 */
function idsOf(data, flat) {
    const ids = {
        nodes: (data.nodes || []).map(idOf),
        edges: (data.edges || []).map(idOf),
        combos: (data.combos || []).map(idOf),
    };
    return flat ? Object.values(ids).flat() : ids;
}
exports.idsOf = idsOf;
//# sourceMappingURL=id.js.map