"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPositionSpecified = exports.isTreeLayout = exports.isComboLayout = void 0;
const util_1 = require("@antv/util");
/**
 * <zh/> 判断是否是 combo 布局
 *
 * <en/> Determine if it is a combo layout
 * @param options - <zh/> 布局配置项 | <en/> Layout options
 * @returns <zh/> 是否是 combo 布局 | <en/> Whether it is a combo layout
 */
function isComboLayout(options) {
    const { type } = options;
    if (['comboCombined', 'comboForce'].includes(type))
        return true;
    if (type === 'antv-dagre' && options.sortByCombo)
        return true;
    return false;
}
exports.isComboLayout = isComboLayout;
/**
 * <zh/> 判断是否是树图布局
 *
 * <en/> Determine if it is a tree layout
 * @param options - <zh/> 布局配置项 | <en/> Layout options
 * @returns <zh/> 是否是树图布局 | <en/> Whether it is a tree layout
 */
function isTreeLayout(options) {
    const { type } = options;
    return ['compact-box', 'mindmap', 'dendrogram', 'indented'].includes(type);
}
exports.isTreeLayout = isTreeLayout;
/**
 * <zh/> 数据中是否指定了位置
 *
 * <en/> Is the position specified in the data
 * @param data - <zh/> 数据 | <en/> Data
 * @returns <zh/> 是否指定了位置 | <en/> Is the position specified
 */
function isPositionSpecified(data) {
    return (0, util_1.isNumber)(data.x) && (0, util_1.isNumber)(data.y);
}
exports.isPositionSpecified = isPositionSpecified;
//# sourceMappingURL=layout.js.map