"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.treeToGraphData = void 0;
const traverse_1 = require("./traverse");
/**
 * <zh/> 将树数据转换为图数据
 *
 * <en/> Convert tree data to graph data
 * @param treeData - <zh/> 树数据 | <en/> Tree data
 * @param getter - <zh/> 获取节点和边的方法 | <en/> Methods to get nodes and edges
 * @returns <zh/> 图数据 | <en/> Graph data
 */
function treeToGraphData(treeData, getter) {
    const { getNodeData = (datum) => {
        if (!datum.children)
            return datum;
        const { children, style = {}, ...restDatum } = datum;
        return { style: { ...style, children: children.map((child) => child.id) }, ...restDatum };
    }, getEdgeData = (source, target) => ({ source: source.id, target: target.id }), getChildren = (datum) => datum.children || [], } = getter || {};
    const nodes = [];
    const edges = [];
    (0, traverse_1.dfs)(treeData, (node) => {
        nodes.push(getNodeData(node));
        const children = getChildren(node);
        for (const child of children) {
            edges.push(getEdgeData(node, child));
        }
    }, (node) => getChildren(node), 'TB');
    return { nodes, edges };
}
exports.treeToGraphData = treeToGraphData;
//# sourceMappingURL=tree.js.map